@@ -17,14 +17,23 @@ import logging
 import itertools
 import time
 
-from libensemble.message_numbers import STOP_TAG, MAN_SIGNAL_FINISH, MAN_SIGNAL_KILL
+from libensemble.message_numbers import (
+    UNSET_TAG,
+    MAN_SIGNAL_FINISH,
+    MAN_SIGNAL_KILL,
+    WORKER_DONE,
+    TASK_FAILED,
+    WORKER_KILL_ON_TIMEOUT,
+    STOP_TAG,
+)
+
 import libensemble.utils.launcher as launcher
 from libensemble.utils.timer import TaskTimer
 
 
 logger = logging.getLogger(__name__)
 # To change logging level for just this module
-# logger.setLevel(logging.DEBUG)
+logger.setLevel(logging.DEBUG)
 
 STATES = """
 UNKNOWN
@@ -35,16 +44,16 @@ FINISHED
 USER_KILLED
 FAILED""".split()
 
-NOT_STARTED_STATES = '''
+NOT_STARTED_STATES = """
 CREATED
 WAITING
-'''.split()
+""".split()
 
-END_STATES = '''
+END_STATES = """
 FINISHED
 USER_KILLED
 FAILED
-'''.split()
+""".split()
 
 
 class ExecutorException(Exception):
@@ -53,12 +62,13 @@ class ExecutorException(Exception):
 
 class TimeoutExpired(Exception):
     """Timeout exception raised when Timeout expires"""
+
     def __init__(self, task, timeout):
         self.task = task
         self.timeout = timeout
 
     def __str__(self):
-        return ("Task {} timed out after {} seconds".format(self.task, self.timeout))
+        return "Task {} timed out after {} seconds".format(self.task, self.timeout)
 
 
 def jassert(test, *args):
@@ -71,19 +81,20 @@ class Application:
     """An application is an executable user-program
     (e.g., implementing a sim/gen function)."""
 
-    prefix = 'libe_app'
+    prefix = "libe_app"
 
-    def __init__(self, full_path, name=None, calc_type='sim', desc=None):
+    def __init__(self, full_path, name=None, calc_type="sim", desc=None, pyobj=None):
         """Instantiates a new Application instance."""
         self.full_path = full_path
         self.calc_type = calc_type
         self.calc_dir, self.exe = os.path.split(full_path)
 
-        if self.exe.endswith('.py'):
-            self.full_path = ' '.join((sys.executable, full_path))
+        if self.exe.endswith(".py"):
+            self.full_path = " ".join((sys.executable, full_path))
         self.name = name or self.exe
-        self.desc = desc or (self.exe + ' app')
-        self.gname = '_'.join([Application.prefix, self.name])
+        self.pyobj = pyobj
+        self.desc = desc or (self.exe + " app")
+        self.gname = "_".join([Application.prefix, self.name])
 
 
 class Task:
@@ -92,11 +103,10 @@ class Task:
 
     """
 
-    prefix = 'libe_task'
+    prefix = "libe_task"
     newid = itertools.count()
 
-    def __init__(self, app=None, app_args=None, workdir=None,
-                 stdout=None, stderr=None, workerid=None, dry_run=False):
+    def __init__(self, app=None, app_args=None, workdir=None, stdout=None, stderr=None, workerid=None, dry_run=False):
         """Instantiate a new Task instance.
 
         A new task object is created with an id, status and configuration
@@ -113,14 +123,12 @@ class Task:
         self.app_args = app_args
         self.workerID = workerid
 
-        jassert(app is not None,
-                "Task must be created with an app - no app found for task {}".
-                format(self.id))
+        jassert(app is not None, "Task must be created with an app - no app found for task {}".format(self.id))
 
         worker_name = "_worker{}".format(self.workerID) if self.workerID else ""
         self.name = Task.prefix + "_{}{}_{}".format(app.name, worker_name, self.id)
-        self.stdout = stdout or self.name + '.out'
-        self.stderr = stderr or self.name + '.err'
+        self.stdout = stdout or self.name + ".out"
+        self.stderr = stderr or self.name + ".err"
         self.workdir = workdir
         self.dry_run = dry_run
         self.runline = None
@@ -128,7 +136,7 @@ class Task:
 
     def reset(self):
         # Status attributes
-        self.state = 'CREATED'
+        self.state = "CREATED"
         self.process = None
         self.errcode = None
         self.finished = False  # True means task ran, not that it succeeded
@@ -143,15 +151,13 @@ class Task:
 
     def file_exists_in_workdir(self, filename):
         """Returns true if the named file exists in the task's workdir"""
-        return (self.workdir
-                and os.path.exists(os.path.join(self.workdir, filename)))
+        return self.workdir and os.path.exists(os.path.join(self.workdir, filename))
 
     def read_file_in_workdir(self, filename):
-        """Opens and reads the named file in the task's workdir """
+        """Opens and reads the named file in the task's workdir"""
         path = os.path.join(self.workdir, filename)
         if not os.path.exists(path):
-            raise ValueError("{} not found in working directory".
-                             format(filename))
+            raise ValueError("{} not found in working directory".format(filename))
         with open(path) as f:
             return f.read()
 
@@ -185,13 +191,13 @@ class Task:
 
     def _check_poll(self):
         """Check whether polling this task makes sense."""
-        jassert(self.process is not None,
-                "Polled task {} has no process ID - check tasks been launched".
-                format(self.name))
+        jassert(
+            self.process is not None, "Polled task {} has no process ID - check tasks been launched".format(self.name)
+        )
         if self.finished:
-            logger.debug("Polled task {} has already finished. "
-                         "Not re-polling. Status is {}".
-                         format(self.name, self.state))
+            logger.debug(
+                "Polled task {} has already finished. " "Not re-polling. Status is {}".format(self.name, self.state)
+            )
             return False
         return True
 
@@ -200,14 +206,13 @@ class Task:
         self.finished = True
         if dry_run:
             self.success = True
-            self.state = 'FINISHED'
+            self.state = "FINISHED"
         else:
             self.calc_task_timing()
             self.errcode = self.process.returncode
-            self.success = (self.errcode == 0)
-            self.state = 'FINISHED' if self.success else 'FAILED'
-            logger.info("Task {} finished with errcode {} ({})".
-                        format(self.name, self.errcode, self.state))
+            self.success = self.errcode == 0
+            self.state = "FINISHED" if self.success else "FAILED"
+            logger.info("Task {} finished with errcode {} ({})".format(self.name, self.errcode, self.state))
 
     def poll(self):
         """Polls and updates the status attributes of the task"""
@@ -220,7 +225,7 @@ class Task:
         # Poll the task
         poll = self.process.poll()
         if poll is None:
-            self.state = 'RUNNING'
+            self.state = "RUNNING"
             self.runtime = self.timer.elapsed
             return
 
@@ -250,6 +255,36 @@ class Task:
 
         self._set_complete()
 
+    def result(self, timeout=None):
+        """Wrapper for task.wait() that also returns the task's status on completion.
+
+        Parameters
+        ----------
+
+        timeout:
+            Time in seconds after which a TimeoutExpired exception is raised"""
+        self.wait(timeout=timeout)
+        return self.state
+
+    def exception(self, timeout=None):
+        """Wrapper for task.wait() that instead returns the task's error code on completion.
+
+        Parameters
+        ----------
+
+        timeout:
+            Time in seconds after which a TimeoutExpired exception is raised"""
+        self.wait(timeout=timeout)
+        return self.errcode
+
+    def running(self):
+        """Return ```True`` if task is currently running."""
+        return self.state == "RUNNING"
+
+    def done(self):
+        """Return ```True`` if task is finished."""
+        return self.finished
+
     def kill(self, wait_time=60):
         """Kills or cancels the supplied task
 
@@ -262,22 +297,32 @@ class Task:
             return
 
         if self.finished:
-            logger.warning("Trying to kill task that is no longer running. "
-                           "Task {}: Status is {}".format(self.name, self.state))
+            logger.warning(
+                "Trying to kill task that is no longer running. Task {}: Status is {}".format(self.name, self.state)
+            )
             return
 
         if self.process is None:
             time.sleep(0.2)
-            jassert(self.process is not None,
-                    "Attempting to kill task {} that has no process ID - "
-                    "check tasks been launched".format(self.name))
+            jassert(
+                self.process is not None,
+                "Attempting to kill task {} that has no process ID - check tasks been launched".format(self.name),
+            )
 
         logger.info("Killing task {}".format(self.name))
         launcher.cancel(self.process, wait_time)
-        self.state = 'USER_KILLED'
+        self.state = "USER_KILLED"
         self.finished = True
         self.calc_task_timing()
 
+    def cancel(self):
+        """Wrapper for task.kill() without waiting"""
+        self.kill(wait_time=None)
+
+    def cancelled(self):
+        """Return ```True`` if task successfully cancelled."""
+        return self.state == "USER_KILLED"
+
 
 class Executor:
     """The executor can create, poll and kill runnable tasks
@@ -294,20 +339,20 @@ class Executor:
 
     executor = None
 
-    def _wait_on_run(self, task, fail_time=None):
-        '''Called by submit when wait_on_run is True.
+    def _wait_on_start(self, task, fail_time=None):
+        """Called by submit when wait_on_start is True.
 
         Blocks until task polls as having started.
         If fail_time is supplied, will also block until either task is in an
         end state or fail_time has expired.
-        '''
+        """
         start = time.time()
         task.timer.start()  # To ensure a start time before poll - will be overwritten unless finished by poll.
         task.submit_time = task.timer.tstart
         while task.state in NOT_STARTED_STATES:
             time.sleep(0.02)
             task.poll()
-        logger.debug("Task {} polled as {} after {} seconds".format(task.name, task.state, time.time()-start))
+        logger.debug("Task {} polled as {} after {} seconds".format(task.name, task.state, time.time() - start))
         if not task.finished:
             task.timer.start()
             task.submit_time = task.timer.tstart
@@ -326,9 +371,8 @@ class Executor:
         This is typically created in the user calling script.
 
         """
-        self.top_level_dir = os.getcwd()
-        self.manager_signal = 'none'
-        self.default_apps = {'sim': None, 'gen': None}
+        self.manager_signal = "none"
+        self.default_apps = {"sim": None, "gen": None}
         self.apps = {}
 
         self.wait_time = 60
@@ -337,21 +381,25 @@ class Executor:
         self.comm = None
         Executor.executor = self
 
-    def _serial_setup(self):
-        pass  # To be overloaded
+    def __enter__(self):
+        return self
 
-    def add_comm_info(self, libE_nodes, serial_setup):
+    def __exit__(self, *exc):
+        pass
+
+    def serial_setup(self):
+        """Set up to be called by only one process"""
         pass  # To be overloaded
 
     @property
     def sim_default_app(self):
         """Returns the default simulation app"""
-        return self.default_apps['sim']
+        return self.default_apps["sim"]
 
     @property
     def gen_default_app(self):
         """Returns the default generator app"""
-        return self.default_apps['gen']
+        return self.default_apps["gen"]
 
     def get_app(self, app_name):
         """Gets the app for a given app_name or raise exception"""
@@ -359,19 +407,23 @@ class Executor:
             app = self.apps[app_name]
         except KeyError:
             app_keys = list(self.apps.keys())
-            raise ExecutorException("Application {} not found in registry".format(app_name),
-                                    "Registered applications: {}".format(app_keys))
+            raise ExecutorException(
+                "Application {} not found in registry".format(app_name), "Registered applications: {}".format(app_keys)
+            )
         return app
 
     def default_app(self, calc_type):
         """Gets the default app for a given calc type"""
         app = self.default_apps.get(calc_type)
-        jassert(calc_type in ['sim', 'gen'],
-                "Unrecognized calculation type", calc_type)
+        jassert(calc_type in ["sim", "gen"], "Unrecognized calculation type", calc_type)
         jassert(app, "Default {} app is not set".format(calc_type))
         return app
 
-    def register_calc(self, full_path, app_name=None, calc_type=None, desc=None):
+    def set_resources(self, resources):
+        # Does not use resources
+        pass
+
+    def register_app(self, full_path, app_name=None, calc_type=None, desc=None):
         """Registers a user application to libEnsemble.
 
         The ``full_path`` of the application must be supplied. Either
@@ -402,8 +454,7 @@ class Executor:
 
         # Default sim/gen apps will be deprecated. Just use names.
         if calc_type is not None:
-            jassert(calc_type in self.default_apps,
-                    "Unrecognized calculation type", calc_type)
+            jassert(calc_type in self.default_apps, "Unrecognized calculation type", calc_type)
             self.default_apps[calc_type] = self.apps[app_name]
 
     def manager_poll(self):
@@ -416,7 +467,7 @@ class Executor:
 
         """
 
-        self.manager_signal = 'none'  # Reset
+        self.manager_signal = "none"  # Reset
 
         # Check for messages; disregard anything but a stop signal
         if not self.comm.mail_flag():
@@ -426,18 +477,80 @@ class Executor:
             return
 
         # Process the signal and push back on comm (for now)
-        logger.info('Worker received kill signal {} from manager'.format(man_signal))
+        logger.info("Worker received kill signal {} from manager".format(man_signal))
         if man_signal == MAN_SIGNAL_FINISH:
-            self.manager_signal = 'finish'
+            self.manager_signal = "finish"
         elif man_signal == MAN_SIGNAL_KILL:
-            self.manager_signal = 'kill'
+            self.manager_signal = "kill"
         else:
-            logger.warning("Received unrecognized manager signal {} - "
-                           "ignoring".format(man_signal))
+            logger.warning("Received unrecognized manager signal {} - ignoring".format(man_signal))
         self.comm.push_to_buffer(mtag, man_signal)
+        return man_signal
+
+    def polling_loop(self, task, timeout=None, delay=0.1, poll_manager=False):
+        """Optional, blocking, generic task status polling loop. Operates until the task
+        finishes, times out, or is optionally killed via a manager signal. On completion, returns a
+        presumptive :ref:`calc_status<datastruct-calc-status>` integer. Potentially useful
+        for running an application via the Executor until it stops without monitoring
+        its intermediate output.
+
+        Parameters
+        ----------
+
+        task: object
+            a Task object returned by the executor on submission
+
+        timeout: int, optional
+            Maximum number of seconds for the polling loop to run. Tasks that run
+            longer than this limit are killed. Default: No timeout
+
+        delay: int, optional
+            Sleep duration between polling loop iterations. Default: 0.1 seconds
+
+        poll_manager: bool, optional
+            Whether to also poll the manager for 'finish' or 'kill' signals.
+            If detected, the task is killed. Default: False.
+
+        Returns
+        -------
+        calc_status: int
+            presumptive integer attribute describing the final status of a launched task
+
+        """
+
+        calc_status = UNSET_TAG
+
+        while not task.finished:
+            task.poll()
+
+            if poll_manager:
+                man_signal = self.manager_poll()
+                if self.manager_signal != "none":
+                    task.kill()
+                    calc_status = man_signal
+                    break
+
+            if timeout is not None and task.runtime > timeout:
+                task.kill()
+                calc_status = WORKER_KILL_ON_TIMEOUT
+                break
+
+            time.sleep(delay)
+
+        if calc_status == UNSET_TAG:
+            if task.state == "FINISHED":
+                calc_status = WORKER_DONE
+            elif task.state == "FAILED":
+                calc_status = TASK_FAILED
+            else:
+                logger.warning(
+                    "Warning: Task {} in unknown state {}. Error code {}".format(self.name, self.state, self.errcode)
+                )
+
+        return calc_status
 
     def get_task(self, taskid):
-        """ Returns the task object for the supplied task ID """
+        """Returns the task object for the supplied task ID"""
         task = next((j for j in self.list_of_tasks if j.id == taskid), None)
         if task is None:
             logger.warning("Task {} not found in tasklist".format(taskid))
@@ -452,8 +565,9 @@ class Executor:
         self.workerID = workerid
         self.comm = comm
 
-    def submit(self, calc_type=None, app_name=None, app_args=None,
-               stdout=None, stderr=None, dry_run=False, wait_on_run=False):
+    def submit(
+        self, calc_type=None, app_name=None, app_args=None, stdout=None, stderr=None, dry_run=False, wait_on_start=False
+    ):
         """Create a new task and run as a local serial subprocess.
 
         The created task object is returned.
@@ -482,7 +596,7 @@ class Executor:
             Whether this is a dry_run - no task will be launched; instead
             runline is printed to logger (at INFO level)
 
-        wait_on_run: boolean, optional
+        wait_on_start: boolean, optional
             Whether to wait for task to be polled as RUNNING (or other
             active/end state) before continuing
 
@@ -490,7 +604,7 @@ class Executor:
         -------
 
         task: obj: Task
-            The lauched task object
+            The launched task object
 
         """
 
@@ -508,18 +622,20 @@ class Executor:
             runline.extend(task.app_args.split())
 
         if dry_run:
-            logger.info('Test (No submit) Runline: {}'.format(' '.join(runline)))
+            logger.info("Test (No submit) Runline: {}".format(" ".join(runline)))
         else:
             # Launch Task
-            logger.info("Launching task {}: {}".
-                        format(task.name, " ".join(runline)))
-            with open(task.stdout, 'w') as out, open(task.stderr, 'w') as err:
-                task.process = launcher.launch(runline, cwd='./',
-                                               stdout=out,
-                                               stderr=err,
-                                               start_new_session=False)
-            if (wait_on_run):
-                self._wait_on_run(task, 0)  # No fail time as no re-starts in-place
+            logger.info("Launching task {}: {}".format(task.name, " ".join(runline)))
+            with open(task.stdout, "w") as out, open(task.stderr, "w") as err:
+                task.process = launcher.launch(
+                    runline,
+                    cwd="./",
+                    stdout=out,
+                    stderr=err,
+                    start_new_session=False,
+                )
+            if wait_on_start:
+                self._wait_on_start(task, 0)  # No fail time as no re-starts in-place
 
             if not task.timer.timing:
                 task.timer.start()
