@@ -5,8 +5,7 @@ from itertools import groupby
 from operator import itemgetter
 
 from libensemble.utils.loc_stack import LocationStack
-from libensemble.tools.fields_keys import libE_spec_sim_dir_keys, libE_spec_gen_dir_keys, \
-    libE_spec_calc_dir_misc
+from libensemble.tools.fields_keys import libE_spec_sim_dir_keys, libE_spec_gen_dir_keys, libE_spec_calc_dir_misc
 from libensemble.message_numbers import EVAL_SIM_TAG, calc_type_strings
 
 
@@ -45,17 +44,17 @@ class EnsembleDirectory:
         self.loc_stack = loc_stack
 
         if self.specs is not None:
-            self.prefix = self.specs.get('ensemble_dir_path', './ensemble')
-            self.use_worker_dirs = self.specs.get('use_worker_dirs', False)
-            self.sim_input_dir = self.specs.get('sim_input_dir', '').rstrip('/')
-            self.sim_dirs_make = self.specs.get('sim_dirs_make', False)
-            self.sim_dir_copy_files = self.specs.get('sim_dir_copy_files', [])
-            self.sim_dir_symlink_files = self.specs.get('sim_dir_symlink_files', [])
-            self.gen_input_dir = self.specs.get('gen_input_dir', '').rstrip('/')
-            self.gen_dirs_make = self.specs.get('gen_dirs_make', False)
-            self.gen_dir_copy_files = self.specs.get('gen_dir_copy_files', [])
-            self.gen_dir_symlink_files = self.specs.get('gen_dir_symlink_files', [])
-            self.ensemble_copy_back = self.specs.get('ensemble_copy_back', False)
+            self.prefix = self.specs.get("ensemble_dir_path", "./ensemble")
+            self.use_worker_dirs = self.specs.get("use_worker_dirs", False)
+            self.sim_input_dir = self.specs.get("sim_input_dir", "").rstrip("/")
+            self.sim_dirs_make = self.specs.get("sim_dirs_make", False)
+            self.sim_dir_copy_files = self.specs.get("sim_dir_copy_files", [])
+            self.sim_dir_symlink_files = self.specs.get("sim_dir_symlink_files", [])
+            self.gen_input_dir = self.specs.get("gen_input_dir", "").rstrip("/")
+            self.gen_dirs_make = self.specs.get("gen_dirs_make", False)
+            self.gen_dir_copy_files = self.specs.get("gen_dir_copy_files", [])
+            self.gen_dir_symlink_files = self.specs.get("gen_dir_symlink_files", [])
+            self.ensemble_copy_back = self.specs.get("ensemble_copy_back", False)
             self.sim_use = any([i in self.specs for i in libE_spec_sim_dir_keys + libE_spec_calc_dir_misc])
             self.gen_use = any([i in self.specs for i in libE_spec_gen_dir_keys + libE_spec_calc_dir_misc])
 
@@ -63,7 +62,7 @@ class EnsembleDirectory:
         """Make copyback directory, adding suffix if identical to ensemble dir"""
         copybackdir = os.path.basename(self.prefix)  # Current directory, same basename
         if os.path.relpath(self.prefix) == os.path.relpath(copybackdir):
-            copybackdir += '_back'
+            copybackdir += "_back"
         os.makedirs(copybackdir)
 
     def make_copyback_check(self):
@@ -87,25 +86,25 @@ class EnsembleDirectory:
 
     @staticmethod
     def extract_H_ranges(Work):
-        """Convert received H_rows into ranges for labeling """
-        work_H_rows = Work['libE_info']['H_rows']
+        """Convert received H_rows into ranges for labeling"""
+        work_H_rows = Work["libE_info"]["H_rows"]
         if len(work_H_rows) == 1:
             return str(work_H_rows[0])
         else:
             # From https://stackoverflow.com/a/30336492
             ranges = []
-            for diff, group in groupby(enumerate(work_H_rows.tolist()), lambda x: x[0]-x[1]):
+            for diff, group in groupby(enumerate(work_H_rows.tolist()), lambda x: x[0] - x[1]):
                 group = list(map(itemgetter(1), group))
                 if len(group) > 1:
-                    ranges.append(str(group[0]) + '-' + str(group[-1]))
+                    ranges.append(str(group[0]) + "-" + str(group[-1]))
                 else:
                     ranges.append(str(group[0]))
-            return '_'.join(ranges)
+            return "_".join(ranges)
 
     def _make_calc_dir(self, workerID, H_rows, calc_str, locs):
         """Create calc dirs and intermediate dirs, copy inputs, based on libE_specs"""
 
-        if calc_str == 'sim':
+        if calc_str == "sim":
             input_dir = self.sim_input_dir
             do_calc_dirs = self.sim_dirs_make
             copy_files = self.sim_dir_copy_files
@@ -139,8 +138,14 @@ class EnsembleDirectory:
                 dir = self.prefix
                 prefix = None
 
-            locs.register_loc(key, dir, prefix=prefix, copy_files=copy_files,
-                              symlink_files=symlink_files, ignore_FileExists=True)
+            locs.register_loc(
+                key,
+                dir,
+                prefix=prefix,
+                copy_files=copy_files,
+                symlink_files=symlink_files,
+                ignore_FileExists=True,
+            )
             return key
 
         # All cases now should involve sim_dirs or gen_dirs
@@ -160,10 +165,13 @@ class EnsembleDirectory:
             calc_prefix = self.prefix
 
         # Register calc dir with adjusted parent dir and source-file location
-        locs.register_loc(calc_dir, calc_dir,  # Dir name also label in loc stack dict
-                          prefix=calc_prefix,
-                          copy_files=copy_files,
-                          symlink_files=symlink_files)
+        locs.register_loc(
+            calc_dir,
+            calc_dir,  # Dir name also label in loc stack dict
+            prefix=calc_prefix,
+            copy_files=copy_files,
+            symlink_files=symlink_files,
+        )
 
         return calc_dir
 
@@ -188,13 +196,12 @@ class EnsembleDirectory:
         """Copy back all ensemble dir contents to launch location"""
         if os.path.isdir(self.prefix) and self.ensemble_copy_back:
 
-            no_calc_dirs = not self.sim_dirs_make or \
-                not self.gen_dirs_make
+            no_calc_dirs = not self.sim_dirs_make or not self.gen_dirs_make
 
             copybackdir = os.path.basename(self.prefix)
 
             if os.path.relpath(self.prefix) == os.path.relpath(copybackdir):
-                copybackdir += '_back'
+                copybackdir += "_back"
 
             for dir in self.loc_stack.dirs.values():
                 dest_path = os.path.join(copybackdir, os.path.basename(dir))
@@ -202,7 +209,7 @@ class EnsembleDirectory:
                     continue  # otherwise, entire ensemble dir copied into copyback dir
 
                 shutil.copytree(dir, dest_path, symlinks=True)
-                if os.path.basename(dir).startswith('worker'):
+                if os.path.basename(dir).startswith("worker"):
                     return  # Worker dir (with all contents) has been copied.
 
             # If not using calc dirs, likely miscellaneous files to copy back
