@@ -10,7 +10,7 @@ import collections
 
 logger = logging.getLogger(__name__)
 
-REMOTE_LAUNCH_LIST = ['aprun', 'jsrun', 'srun']  # Move to feature of mpi_runner
+REMOTE_LAUNCH_LIST = ["aprun", "jsrun", "srun"]  # Move to feature of mpi_runner
 
 
 def get_cpu_cores(hyperthreads=False):
@@ -41,7 +41,8 @@ def _print_local_cpu_resources():
 def _get_remote_cpu_resources(launcher):
     """Launches a probe job to obtain logical and physical cores on remote node"""
     import subprocess
-    output = subprocess.check_output([launcher, 'python', __file__])
+
+    output = subprocess.check_output([launcher, "python", __file__])
     return output.decode()
 
 
@@ -52,16 +53,16 @@ def _get_cpu_resources_from_env(env_resources=None):
         return None
 
     found_count = False
-    if env_resources.nodelists['LSF'] in os.environ:
-        full_list = os.environ.get(env_resources.nodelists['LSF']).split()
-        nodes = [n for n in full_list if 'batch' not in n]
+    if env_resources.nodelists["LSF"] in os.environ:
+        full_list = os.environ.get(env_resources.nodelists["LSF"]).split()
+        nodes = [n for n in full_list if "batch" not in n]
         counter = list(collections.Counter(nodes).values())
         found_count = True
-    elif env_resources.nodelists['LSF_shortform'] in os.environ:
-        full_list = os.environ.get(env_resources.nodelists['LSF_shortform']).split()
+    elif env_resources.nodelists["LSF_shortform"] in os.environ:
+        full_list = os.environ.get(env_resources.nodelists["LSF_shortform"]).split()
         iter_list = iter(full_list)
         zipped_list = list(zip(iter_list, iter_list))
-        nodes_with_count = [n for n in zipped_list if 'batch' not in n[0]]
+        nodes_with_count = [n for n in zipped_list if "batch" not in n[0]]
         counter = [int(n[1]) for n in nodes_with_count]
         found_count = True
 
@@ -86,7 +87,7 @@ def get_sub_node_resources(launcher=None, remote_mode=False, env_resources=None)
         if launcher in REMOTE_LAUNCH_LIST:
             cores_info = _get_cpu_resources_from_env(env_resources=env_resources)
             if cores_info:
-                return (cores_info)
+                return cores_info
             remote_detection = True  # Cannot obtain from environment
 
     if remote_detection:
@@ -95,7 +96,7 @@ def get_sub_node_resources(launcher=None, remote_mode=False, env_resources=None)
         cores_info = (int(cores_log), int(cores_phy))
     else:
         cores_info = _get_local_cpu_resources()
-    return (cores_info)
+    return cores_info
 
 
 if __name__ == "__main__":
