@@ -28,40 +28,44 @@ def run_warpx(H, persis_info, sim_specs, libE_info):
 
     calc_status = 0  # Returns to worker
 
-    input_file = sim_specs['user']['input_filename']
-    time_limit = sim_specs['user']['sim_kill_minutes'] * 60.0
-    machine_specs = sim_specs['user']['machine_specs']
+    input_file = sim_specs["user"]["input_filename"]
+    time_limit = sim_specs["user"]["sim_kill_minutes"] * 60.0
+    machine_specs = sim_specs["user"]["machine_specs"]
 
     exctr = Executor.executor  # Get Executor
 
     # Modify WarpX input file with input parameters calculated by gen_f
     # and passed to this sim_f.
-    write_sim_input(input_file, H['x'])
+    write_sim_input(input_file, H["x"])
 
     # Passed to command line in addition to the executable.
     # Here, only input file
     app_args = input_file
-    os.environ["OMP_NUM_THREADS"] = machine_specs['OMP_NUM_THREADS']
+    os.environ["OMP_NUM_THREADS"] = machine_specs["OMP_NUM_THREADS"]
 
     # Launch the executor to actually run the WarpX simulation
-    if machine_specs['name'] == 'summit':
-        task = exctr.submit(app_name='warpx',
-                            extra_args=machine_specs['extra_args'],
-                            app_args=app_args,
-                            stdout='out.txt',
-                            stderr='err.txt',
-                            wait_on_start=True)
+    if machine_specs["name"] == "summit":
+        task = exctr.submit(
+            app_name="warpx",
+            extra_args=machine_specs["extra_args"],
+            app_args=app_args,
+            stdout="out.txt",
+            stderr="err.txt",
+            wait_on_start=True,
+        )
     else:
-        task = exctr.submit(app_name='warpx',
-                            num_procs=machine_specs['cores'],
-                            app_args=app_args,
-                            stdout='out.txt',
-                            stderr='err.txt',
-                            wait_on_start=True)
+        task = exctr.submit(
+            app_name="warpx",
+            num_procs=machine_specs["cores"],
+            app_args=app_args,
+            stdout="out.txt",
+            stderr="err.txt",
+            wait_on_start=True,
+        )
 
     # Periodically check the status of the simulation
     poll_interval = 1  # secs
-    while(not task.finished):
+    while not task.finished:
         time.sleep(poll_interval)
         task.poll()
         if task.runtime > time_limit:
@@ -69,18 +73,15 @@ def run_warpx(H, persis_info, sim_specs, libE_info):
 
     # Set calc_status with optional prints.
     if task.finished:
-        if task.state == 'FINISHED':
+        if task.state == "FINISHED":
             calc_status = WORKER_DONE
-        elif task.state == 'FAILED':
-            print("Warning: Task {} failed: Error code {}"
-                  .format(task.name, task.errcode))
+        elif task.state == "FAILED":
+            print("Warning: Task {} failed: Error code {}".format(task.name, task.errcode))
             calc_status = TASK_FAILED
-        elif task.state == 'USER_KILLED':
-            print("Warning: Task {} has been killed"
-                  .format(task.name))
+        elif task.state == "USER_KILLED":
+            print("Warning: Task {} has been killed".format(task.name))
         else:
-            print("Warning: Task {} in unknown state {}. Error code {}"
-                  .format(task.name, task.state, task.errcode))
+            print("Warning: Task {} in unknown state {}. Error code {}".format(task.name, task.state, task.errcode))
 
     # Safety
     time.sleep(0.2)
@@ -90,25 +91,25 @@ def run_warpx(H, persis_info, sim_specs, libE_info):
         warpx_out = read_sim_output(task.workdir)
     except Exception:
         warpx_out = np.nan
-        print('Warning - output is Nan')
+        print("Warning - output is Nan")
 
     # Pass the sim output values to LibEnsemble.
     # When optimization is ON, 'f' is then passed to the generating function
     # gen_f to generate new inputs for next runs.
     # All other parameters are here just for convenience.
-    libE_output = np.zeros(1, dtype=sim_specs['out'])
+    libE_output = np.zeros(1, dtype=sim_specs["out"])
 
     if np.isnan(warpx_out):
-        libE_output['f'] = np.nan
+        libE_output["f"] = np.nan
     else:
-        libE_output['f'] = warpx_out[0]
-        libE_output['energy_std'] = warpx_out[1]
-        libE_output['energy_avg'] = warpx_out[2]
-        libE_output['charge'] = warpx_out[3]
-        libE_output['emittance'] = warpx_out[4]
-        libE_output['ramp_down_1'] = H['x'][0][0]
-        libE_output['ramp_down_2'] = H['x'][0][1]
-        libE_output['zlens_1'] = H['x'][0][2]
-        libE_output['adjust_factor'] = H['x'][0][3]
+        libE_output["f"] = warpx_out[0]
+        libE_output["energy_std"] = warpx_out[1]
+        libE_output["energy_avg"] = warpx_out[2]
+        libE_output["charge"] = warpx_out[3]
+        libE_output["emittance"] = warpx_out[4]
+        libE_output["ramp_down_1"] = H["x"][0][0]
+        libE_output["ramp_down_2"] = H["x"][0][1]
+        libE_output["zlens_1"] = H["x"][0][2]
+        libE_output["adjust_factor"] = H["x"][0][3]
 
     return libE_output, persis_info, calc_status
