@@ -6,16 +6,16 @@ import numpy as np
 if len(sys.argv) > 1:
     results = np.load(sys.argv[1])
 else:
-    print('You need to supply an .npy file - aborting')
+    print("You need to supply an .npy file - aborting")
     sys.exit()
 
 done_only = False
 dtype_only = False
 
 if len(sys.argv) > 2:
-    if sys.argv[2] == 'done':
+    if sys.argv[2] == "done":
         done_only = True
-    elif sys.argv[2] == 'dtype':
+    elif sys.argv[2] == "dtype":
         dtype_only = True
 else:
     print(repr(results))
@@ -23,13 +23,13 @@ else:
 if done_only:
     count = 0
     for line in results:
-        if line['returned']:
+        if line["sim_ended"]:
             count += 1
 
     results_filtered = np.zeros(count, dtype=results.dtype)
     count = 0
     for i, line in enumerate(results):
-        if line['returned']:
+        if line["sim_ended"]:
             results_filtered[count] = results[i]
             count += 1
 
